@@ -30,7 +30,7 @@ class ExecutionServer(BaseServer):
     job_queue = []
     job_count = 0
     query_start_time = None
-    simultaneous_jobs = 50
+    simultaneous_jobs = 5
     querying_for_jobs = False
     reservation_update_queue = []
     current_sql = ""
@@ -562,8 +562,7 @@ class ExecutionServer(BaseServer):
             # Call the function.
             LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
             # Schedule the next request.
-            reactor.callLater(0, 
-                self._callExposedFunction,
+            self._callExposedFunction(
                 exposed_function["function"],
                 exposed_function["interval"], 
                 kwargs, 
